==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mi/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Rawa Ritenga',
    'field'		                => 'Āpure',
    'about_fieldsets_title'		=> 'Mō Ngā Āpure',
    'about_fieldsets_text'		=> 'Ka taea e nga maraahi ki a koe te hanga i nga roopu o nga mahinga ritenga e whakamahia ana mo nga momo waahanga motuhake.',
    'custom_format'             => 'Taeranga Ritenga ...',
    'encrypt_field'      	        => 'Whakamunahia te uara o tenei mara i roto i te pātengi raraunga',
    'encrypt_field_help'      => 'WARNING: Ko te whakamunatanga o te mara kaore e kitea.',
    'encrypted'      	        => 'Kua whakamunatia',
    'fieldset'      	        => 'Whakaputu',
    'qty_fields'      	      => 'Utu Nga Tae',
    'fieldsets'      	        => 'Ngā Āpure',
    'fieldset_name'           => 'Ingoa Fieldset',
    'field_name'              => 'Ingoa Āpure',
    'field_values'            => 'Ngā Uara Āpure',
    'field_values_help'       => 'Tāpirihia he kōwhiringa whiriwhiri, kotahi ia raina. Ko nga raina koreina atu i te raina tuatahi ka waihohia.',
    'field_element'           => 'Puka Puka',
    'field_element_short'     => 'Tuhinga',
    'field_format'            => 'Whakahōputu',
    'field_custom_format'     => 'Whakaritenga Ritenga',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'E hiahiatia ana',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Kua Whakamahia Ma Nga Tauira',
    'order'   		            => 'Whakatau',
    'create_fieldset'         => 'Nga Pakanga Hou',
    'create_field'            => 'Rawa Ritenga Hou',
    'value_encrypted'      	        => 'Ko te uara o tenei mara kei te whakamunatia i roto i te pātengi raraunga. Ka taea anake e nga kaiwhakahaere ka kite i te uara kua tohua',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mi/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Rawa Ritenga',
    'manage'                    => 'Manage',
    'field'		                => 'Āpure',
    'about_fieldsets_title'		=> 'Mō Ngā Āpure',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Whakamunahia te uara o tenei mara i roto i te pātengi raraunga',
    'encrypt_field_help'      => 'WARNING: Ko te whakamunatanga o te mara kaore e kitea.',
    'encrypted'      	        => 'Kua whakamunatia',
    'fieldset'      	        => 'Whakaputu',
    'qty_fields'      	      => 'Utu Nga Tae',
    'fieldsets'      	        => 'Ngā Āpure',
    'fieldset_name'           => 'Ingoa Fieldset',
    'field_name'              => 'Ingoa Āpure',
    'field_values'            => 'Ngā Uara Āpure',
    'field_values_help'       => 'Tāpirihia he kōwhiringa whiriwhiri, kotahi ia raina. Ko nga raina koreina atu i te raina tuatahi ka waihohia.',
    'field_element'           => 'Puka Puka',
    'field_element_short'     => 'Tuhinga',
    'field_format'            => 'Whakahōputu',
    'field_custom_format'     => 'Whakaritenga Ritenga',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'E hiahiatia ana',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Kua Whakamahia Ma Nga Tauira',
    'order'   		            => 'Whakatau',
    'create_fieldset'         => 'Nga Pakanga Hou',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Rawa Ritenga Hou',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Ko te uara o tenei mara kei te whakamunatia i roto i te pātengi raraunga. Ka taea anake e nga kaiwhakahaere ka kite i te uara kua tohua',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
